"""Metadata for sparkle-log."""

__all__ = [
    "__title__",
    "__version__",
    "__description__",
    "__author__",
    "__author_email__",
    "__keywords__",
    "__status__",
    "__license__",
    "__readme__",
    "__repository__",
    "__homepage__",
    "__documentation__",
]

__title__ = "sparkle-log"
__version__ = "0.3.0"
__description__ = "Write sparkline graphs of CPU and memory usage to your logs."
__author__ = "Matthew Martin"
__author_email__ = "matthewdeanmartin@gmail.com"
__keywords__ = ["monitoring", "logging"]
__status__ = "4 - Beta"
__license__ = "MIT"
__readme__ = "README.md"
__repository__ = "https://github.com/matthewdeanmartin/sparkle_log"
__homepage__ = "https://github.com/matthewdeanmartin/sparkle_log"
__documentation__ = "https://matthewdeanmartin.github.io/sparkle_log/sparkle_log/index.html"
